==> huaweicloudsdkdrs-3.1.131-py2.py3-none-any.whl: huaweicloudsdkdrs/v5/model/show_metering_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowMeteringResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'product_info_list': 'list[ProductInfo]'
    }

    attribute_map = {
        'product_info_list': 'product_info_list'
    }

    def __init__(self, product_info_list=None):
        """ShowMeteringResponse

        The model defined in huaweicloud sdk

        :param product_info_list: 资源信息列表。
        :type product_info_list: list[:class:`huaweicloudsdkdrs.v5.ProductInfo`]
        """
        
        super(ShowMeteringResponse, self).__init__()

        self._product_info_list = None
        self.discriminator = None

        if product_info_list is not None:
            self.product_info_list = product_info_list

    @property
    def product_info_list(self):
        """Gets the product_info_list of this ShowMeteringResponse.

        资源信息列表。

        :return: The product_info_list of this ShowMeteringResponse.
        :rtype: list[:class:`huaweicloudsdkdrs.v5.ProductInfo`]
        """
        return self._product_info_list

    @product_info_list.setter
    def product_info_list(self, product_info_list):
        """Sets the product_info_list of this ShowMeteringResponse.

        资源信息列表。

        :param product_info_list: The product_info_list of this ShowMeteringResponse.
        :type product_info_list: list[:class:`huaweicloudsdkdrs.v5.ProductInfo`]
        """
        self._product_info_list = product_info_list

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowMeteringResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkdrs-3.1.146-py2.py3-none-any.whl: huaweicloudsdkdrs/v5/model/show_metering_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowMeteringResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'product_info_list': 'list[ProductInfo]'
    }

    attribute_map = {
        'product_info_list': 'product_info_list'
    }

    def __init__(self, product_info_list=None):
        r"""ShowMeteringResponse

        The model defined in huaweicloud sdk

        :param product_info_list: 资源信息列表。
        :type product_info_list: list[:class:`huaweicloudsdkdrs.v5.ProductInfo`]
        """
        
        super(ShowMeteringResponse, self).__init__()

        self._product_info_list = None
        self.discriminator = None

        if product_info_list is not None:
            self.product_info_list = product_info_list

    @property
    def product_info_list(self):
        r"""Gets the product_info_list of this ShowMeteringResponse.

        资源信息列表。

        :return: The product_info_list of this ShowMeteringResponse.
        :rtype: list[:class:`huaweicloudsdkdrs.v5.ProductInfo`]
        """
        return self._product_info_list

    @product_info_list.setter
    def product_info_list(self, product_info_list):
        r"""Sets the product_info_list of this ShowMeteringResponse.

        资源信息列表。

        :param product_info_list: The product_info_list of this ShowMeteringResponse.
        :type product_info_list: list[:class:`huaweicloudsdkdrs.v5.ProductInfo`]
        """
        self._product_info_list = product_info_list

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowMeteringResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
